@@ -36,50 +36,48 @@
 #'
 #' @return A data frame of segments and their meta data.
 #'
-#' @import stringr
 #' @export
 #'
 aw_get_segments <- function(company_id = Sys.getenv("AW_COMPANY_ID"),
-                          rsids = NA,
-                          segmentFilter = NA,
+                          rsids = NULL,
+                          segmentFilter = NULL,
                           locale = 'en_US',
-                          name = NA,
-                          tagNames = NA,
+                          name = NULL,
+                          tagNames = NULL,
                           filterByPublishedSegments = 'all',
                           limit = 10,
                           page = 0,
                           sortDirection = 'ASC',
                           sortProperty = 'id',
-                          expansion = NA,
+                          expansion = NULL,
                           includeType = 'all',
                           debug = FALSE)
 {
-  #make the list of params into a dataframe
-  if(length(rsids) > 1) {rsids = paste0(rsids, collapse = ',') }
-  if(length(segmentFilter) > 1) {segmentFilter = paste0(segmentFilter, collapse = ',') }
-  if(length(expansion) > 1) {expansion = paste0(expansion, collapse = ',') }
-  if(!all(is.na(tagNames))) {tagNames = utils::URLencode(paste0(tagNames, collapse = ',')) }
-  if(!all(is.na(name))) {name = utils::URLencode(paste0(name, collapse = ',')) }
+  # Only tagNames, segmentFilter, expansion, and rsids may be vectors
+  # Trying to have multiple names could be a common mistake
+  assertthat::assert_that(length(name) < 2, msg = "'name' is a search string and may not have length > 1\nUse 'segmentFilter' to request specific segments")
 
-  vars <- tibble::tibble(rsids, segmentFilter, locale, name, tagNames, filterByPublishedSegments, limit, page, sortDirection,
-  sortProperty, expansion, includeType)
-  #Turn the list into a string to create the query
-  prequery <- list(vars %>% dplyr::select_if(~ !any(is.na(.))))
-  #remove the extra parts of the string and replace it with the query parameter breaks
-  query_param <- stringr::str_remove_all(stringr::str_replace_all(stringr::str_remove_all(paste(prequery, collapse = ''), '\\"'), ', ', '&'), 'list\\(| |\\)')
+  query_params <- list(
+    rsids = rsids,
+    segmentFilter = segmentFilter,
+    locale = locale,
+    name = name,
+    tagNames = tagNames,
+    filterByPublishedSegments = filterByPublishedSegments,
+    limit = limit,
+    page = page,
+    sortDirection = sortDirection,
+    sortProperty = sortProperty,
+    expansion = expansion,
+    includeType = includeType
+  )
 
-  #create the url to send with the query
-  urlstructure <- paste0('segments?',query_param)
+  urlstructure <- paste('segments', format_URL_parameters(query_params), sep = "?")
+  res <- aw_call_api(req_path = urlstructure, debug = debug, company_id = company_id)
 
-  #urlstructure <- 'segments?locale=en_US&filterByPublishedSegments=all&limit=1000&page=0&sortDirection=ASC&sortProperty=id&includeType=all'
-  res <- aw_call_api(req_path = urlstructure[1], debug = debug, company_id = company_id)
+  jsonlite::fromJSON(res)$content
+}
 
-  res <- jsonlite::fromJSON(res)
 
-  #Just need the content of the returned json
-  res <- res$content
 
-  res
-
-  }
 
